@@ -52,7 +52,8 @@ def get_transition(lancet, issue, to_status):
 
 def assign_issue(lancet, issue, username, active_status=None):
     with taskstatus('Assigning issue to you') as ts:
-        if issue.fields.assignee.key != username:
+        assignee = issue.fields.assignee
+        if not assignee or assignee.key != username:
             if issue.fields.status.name == active_status:
                 ts.fail('Issue already active and not assigned to you',
                         abort=True)
@@ -79,9 +80,13 @@ def main(ctx):
     # TODO: Remove me once not needed anymore
     import warnings
     warnings.simplefilter('ignore', ImportWarning, 2150)
-    warnings.simplefilter('ignore', ResourceWarning)
+
+    # TODO: Enable this using a command line switch
+    # import logging
+    # logging.basicConfig(level=logging.DEBUG)
 
     ctx.obj = Lancet(load_config())
+    ctx.obj.call_on_close = ctx.call_on_close
 
 
 @click.command()
